/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_4S4K2gzt);
  numBytes += sLine_init(&sLine_bF7fisAU);
  numBytes += sTabhead_init(&sTabhead_sEflX4v5, &hTable_B6anryH3);
  numBytes += sTabread_init(&sTabread_CdSoQ3ry, &hTable_B6anryH3, false);
  numBytes += sTabread_init(&sTabread_N0MeNz6H, &hTable_B6anryH3, false);
  numBytes += sLine_init(&sLine_U2ZW7wFJ);
  numBytes += sLine_init(&sLine_KAULjtC0);
  numBytes += sLine_init(&sLine_PulRztVI);
  numBytes += sTabhead_init(&sTabhead_beWKmHdE, &hTable_FevYzhFZ);
  numBytes += sTabread_init(&sTabread_Ya2GmuYd, &hTable_FevYzhFZ, false);
  numBytes += sTabread_init(&sTabread_QFk8qYZi, &hTable_FevYzhFZ, false);
  numBytes += sLine_init(&sLine_azWmzm9Y);
  numBytes += sTabwrite_init(&sTabwrite_hXR5vSXX, &hTable_B6anryH3);
  numBytes += sTabwrite_init(&sTabwrite_9tpoVewW, &hTable_FevYzhFZ);
  numBytes += sRPole_init(&sRPole_pXEHEANm);
  numBytes += sRPole_init(&sRPole_WErpZl35);
  numBytes += sRPole_init(&sRPole_1euco1Tx);
  numBytes += sDel1_init(&sDel1_2qG8Tj8s);
  numBytes += sLine_init(&sLine_fG0rzx8S);
  numBytes += sLine_init(&sLine_nveXsIMc);
  numBytes += sRPole_init(&sRPole_h93gN1r5);
  numBytes += sRPole_init(&sRPole_9IDZnNaH);
  numBytes += sRPole_init(&sRPole_nwoptEYU);
  numBytes += sDel1_init(&sDel1_q9g4JiZz);
  numBytes += sLine_init(&sLine_o0gdV1f7);
  numBytes += sLine_init(&sLine_ttsH1oah);
  numBytes += sLine_init(&sLine_I5b97TPL);
  numBytes += sLine_init(&sLine_rq2opJZm);
  numBytes += cVar_init_f(&cVar_dH0BPU8U, 0.0f);
  numBytes += cVar_init_f(&cVar_enlDntax, 0.0f);
  numBytes += cVar_init_f(&cVar_IF1ySwN6, 0.0f);
  numBytes += cVar_init_f(&cVar_jXIhzPaR, 0.0f);
  numBytes += cSlice_init(&cSlice_GXdb9drL, 1, -1);
  numBytes += cVar_init_f(&cVar_m7C6mXqE, 0.5f);
  numBytes += cSlice_init(&cSlice_coOiiAdT, 1, -1);
  numBytes += cVar_init_f(&cVar_DZYf75z7, 0.2f);
  numBytes += cSlice_init(&cSlice_VYrJGJyb, 1, -1);
  numBytes += cVar_init_f(&cVar_6XWvVs5f, 500.0f);
  numBytes += cSlice_init(&cSlice_2BbZguZ4, 1, -1);
  numBytes += cVar_init_f(&cVar_6mTxCtE6, 0.25f);
  numBytes += cDelay_init(this, &cDelay_JaWRPAWV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_CFpGH8PY, 0.0f);
  numBytes += hTable_init(&hTable_B6anryH3, 256);
  numBytes += cDelay_init(this, &cDelay_Xb5IAQIy, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nnX3VFqD, 0.0f);
  numBytes += hTable_init(&hTable_FevYzhFZ, 256);
  numBytes += cVar_init_f(&cVar_n76P4nb3, 8000.0f);
  numBytes += cBinop_init(&cBinop_pO5Gs2uQ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cm9PoxJG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vDMJxh7z, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H2EezniM, 8000.0f);
  numBytes += cBinop_init(&cBinop_L7RO3Bab, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ernfe2ve, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B7uJLc7P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Jhttv7Px, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wNu3UrY3, 300.0f);
  numBytes += cBinop_init(&cBinop_qHNofJNN, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_wRETMDYR, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_VGqQD9pi, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_Raov78R2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uDdas4Zy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pIPKuBP2, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Z0M2s0WB, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_nT1nUZVF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_q4Q2bFrO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FBPULmIu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6UGwvqPp, 8000.0f);
  numBytes += cBinop_init(&cBinop_ny4iRSPi, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VAH4Lb5P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7KzCCwHO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hd7LNaJM, 8000.0f);
  numBytes += cBinop_init(&cBinop_oMQUj76V, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_blg8DoFC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hfQZbGJZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S8dG0iAP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qpj3XfmE, 300.0f);
  numBytes += cBinop_init(&cBinop_wSJcH6m2, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_BjS3mMMH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K3SCK64Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7SSpR10C, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_9nE15uG0, 1.0f);
  numBytes += cIf_init(&cIf_FsSbn2Mk, false);
  numBytes += cIf_init(&cIf_NrYzpGVr, false);
  numBytes += cVar_init_f(&cVar_DHAba73I, 0.0f);
  numBytes += cVar_init_f(&cVar_BS5Q2h0q, 0.0f);
  numBytes += cVar_init_f(&cVar_QDtECOrW, 60000.0f);
  numBytes += cVar_init_f(&cVar_LM8yN4Gw, 500.0f);
  numBytes += cSlice_init(&cSlice_pIYZBjox, 1, -1);
  numBytes += cSlice_init(&cSlice_tXqqtrZ0, 1, -1);
  numBytes += cVar_init_f(&cVar_TMviFvUc, 0.0f);
  numBytes += cIf_init(&cIf_G3qHG861, false);
  numBytes += cBinop_init(&cBinop_sJwbQj3V, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_ZEK4GfpF, 120.0f);
  numBytes += cBinop_init(&cBinop_L52Rw9ln, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_bsWyDTqy, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_B6anryH3);
  hTable_free(&hTable_FevYzhFZ);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_B6anryH3; // del-1011-delayL
    case 0xF057CB49: return &hTable_FevYzhFZ; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fEpvGyNH_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NqshwU8s_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wJot4Y47_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DAzOVitb_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6vcRQCBV_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qQHzMj0b_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QtqPcuQs_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y4PKzJPp_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CzWqHViX_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1j036xcx_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3bRTD4rd_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PiRt8jce_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_dH0BPU8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yk7BYTwV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_enlDntax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nn7FCQ3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_IF1ySwN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjGTyJ3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_jXIhzPaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CUXOc7tf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_JI6VvjnL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GXdb9drL, 0, m, &cSlice_GXdb9drL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_GXdb9drL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_djI7lQLg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_djI7lQLg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_m7C6mXqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_djI7lQLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_djI7lQLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CzWqHViX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_8cZeh1HX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_coOiiAdT, 0, m, &cSlice_coOiiAdT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_31jyaDEZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_coOiiAdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qn4j4LBR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qn4j4LBR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_DZYf75z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qn4j4LBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_qn4j4LBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QtqPcuQs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_hg5pOrNF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VYrJGJyb, 0, m, &cSlice_VYrJGJyb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JI6VvjnL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_VYrJGJyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AMOrkY4Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AMOrkY4Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_6XWvVs5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AMOrkY4Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_AMOrkY4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1j036xcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_M3ugDbKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jmyNKTfQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jmyNKTfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_zOULNShO_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_WowsXFbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qfCtyoNG_sendMessage(_c, 0, m);
  cMsg_DUFSoGbu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_l2dTSvF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VzH7nboF_sendMessage(_c, 0, m);
  cMsg_ZHdlpLBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_zOULNShO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jGklqFnQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jGklqFnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I3Yc62ub_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DZCr0S4F_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_DZCr0S4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s6tvO0kW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_I3Yc62ub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QZ6fJuk0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QZ6fJuk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zYLSRGQR_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_s6tvO0kW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FWRe4DuE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_FWRe4DuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_d4nT6Zyv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_zYLSRGQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_WowsXFbO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_d4nT6Zyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_l2dTSvF0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7sYVdGlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TgycaGm4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TgycaGm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_GLwKMNRc_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_GLwKMNRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Kk2romSK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Kk2romSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UQfNn930_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xHiyNwc4_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_UQfNn930_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WvLfAAEl_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_xHiyNwc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CTxnssus_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_WvLfAAEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t4499jQI_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_CTxnssus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FrULqHpz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_FrULqHpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XvS7ChVs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XvS7ChVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RglNbk1K_sendMessage(_c, 0, m);
  cMsg_kEcAmste_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_t4499jQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dOxVbAc9_sendMessage(_c, 0, m);
  cMsg_Nwv7Jan9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_31jyaDEZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2BbZguZ4, 0, m, &cSlice_2BbZguZ4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hg5pOrNF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_2BbZguZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cJZh2PEh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cJZh2PEh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_6mTxCtE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cJZh2PEh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_cJZh2PEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Y4PKzJPp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_eD2ILE33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_asm98nLU_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_asm98nLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_udaIz171_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_JaWRPAWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JaWRPAWV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CFpGH8PY, 0, m, &cDelay_CFpGH8PY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JaWRPAWV, 0, m, &cDelay_JaWRPAWV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hXR5vSXX, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_CFpGH8PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CFpGH8PY, m);
  cMsg_0vcNuaW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_kkiIOX2Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_lRWAbghY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_SOuJM6Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_atAhnVFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_B6anryH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AfSsw0gE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JaWRPAWV, 2, m, &cDelay_JaWRPAWV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nbmzWP6a_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_atAhnVFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_B6anryH3, 0, m, &hTable_B6anryH3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_udaIz171_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_SOuJM6Po_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_0vcNuaW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_B6anryH3, 0, m, &hTable_B6anryH3_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_nbmzWP6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JaWRPAWV, 0, m, &cDelay_JaWRPAWV_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_AfSsw0gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_CFpGH8PY, 2, m, &cDelay_CFpGH8PY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lRWAbghY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hXR5vSXX, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_FGVaYdPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tUwEqGNm_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_tUwEqGNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8fGQ4I4e_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_Xb5IAQIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xb5IAQIy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nnX3VFqD, 0, m, &cDelay_nnX3VFqD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xb5IAQIy, 0, m, &cDelay_Xb5IAQIy_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9tpoVewW, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_nnX3VFqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nnX3VFqD, m);
  cMsg_pjjfyOEt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_oVg6SHf4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OB16DVcG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_jrWMI0FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IgjWL06x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_FevYzhFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_luG5GKl6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xb5IAQIy, 2, m, &cDelay_Xb5IAQIy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JGx49eZI_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IgjWL06x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_FevYzhFZ, 0, m, &hTable_FevYzhFZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8fGQ4I4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_jrWMI0FV_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_pjjfyOEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_FevYzhFZ, 0, m, &hTable_FevYzhFZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JGx49eZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xb5IAQIy, 0, m, &cDelay_Xb5IAQIy_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_luG5GKl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nnX3VFqD, 2, m, &cDelay_nnX3VFqD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_OB16DVcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9tpoVewW, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_n76P4nb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pO5Gs2uQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_pO5Gs2uQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sIkAA8uN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vGIIHTs1_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_vGIIHTs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_twu8ScE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_pO5Gs2uQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uemk64M2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_k8Ug9lpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pO5Gs2uQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_pO5Gs2uQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_twu8ScE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_k8Ug9lpI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_uemk64M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DonawLwT_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_DonawLwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qWG5DDC0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vDMJxh7z, m);
}

void Heavy_WSTD_DLAY::cBinop_qWG5DDC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cm9PoxJG, m);
}

void Heavy_WSTD_DLAY::cVar_H2EezniM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L7RO3Bab, HV_BINOP_MULTIPLY, 0, m, &cBinop_L7RO3Bab_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_YyY7QahA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kxrbVIGG_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_kxrbVIGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZhdpMuKr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_L7RO3Bab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0cOv4GVa_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_D7pC7YSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L7RO3Bab, HV_BINOP_MULTIPLY, 1, m, &cBinop_L7RO3Bab_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZhdpMuKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_D7pC7YSz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0cOv4GVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dGjSgjZF_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dGjSgjZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7f3PHJbd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_B7uJLc7P, m);
}

void Heavy_WSTD_DLAY::cBinop_7f3PHJbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ernfe2ve, m);
}

void Heavy_WSTD_DLAY::cBinop_aeHHQ3K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4hlOHCef_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4hlOHCef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jtmr74QS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8fBCijK2_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_wNu3UrY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_2nKrYAHs_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lpyr7skc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6K82KAnW_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_6K82KAnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHNofJNN, HV_BINOP_DIVIDE, 1, m, &cBinop_qHNofJNN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jtmr74QS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_f1zBCUVL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_f1zBCUVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wRETMDYR, m);
}

void Heavy_WSTD_DLAY::cMsg_DDELUWtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d9qKF3JA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_d9qKF3JA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aeHHQ3K3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8fBCijK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Jhttv7Px, m);
}

void Heavy_WSTD_DLAY::cBinop_2nKrYAHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_1aeoAfgO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1aeoAfgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qHNofJNN, HV_BINOP_DIVIDE, 0, m, &cBinop_qHNofJNN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qHNofJNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DDELUWtR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_F6bAWh5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zXTw72Es_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_zXTw72Es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YBQEuWZq_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_VGqQD9pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PWIsPzWV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_XrrtiLlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QToQ8GP0_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Raov78R2, m);
}

void Heavy_WSTD_DLAY::cBinop_YBQEuWZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uDdas4Zy, m);
}

void Heavy_WSTD_DLAY::cMsg_PWIsPzWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XrrtiLlB_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QToQ8GP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pIPKuBP2, m);
}

void Heavy_WSTD_DLAY::cMsg_TsaUSHuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_P58rRX3A_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_P58rRX3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GmY02Bkw_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Z0M2s0WB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iwT1dz76_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_UTxi4N9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7ByZLnnv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nT1nUZVF, m);
}

void Heavy_WSTD_DLAY::cBinop_GmY02Bkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_q4Q2bFrO, m);
}

void Heavy_WSTD_DLAY::cMsg_iwT1dz76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UTxi4N9I_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7ByZLnnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FBPULmIu, m);
}

void Heavy_WSTD_DLAY::cVar_6UGwvqPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ny4iRSPi, HV_BINOP_MULTIPLY, 0, m, &cBinop_ny4iRSPi_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cPoTwHUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UMVjVrq2_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_UMVjVrq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kFl1YCSB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ny4iRSPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lIPJA2Xv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_cac99iy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ny4iRSPi, HV_BINOP_MULTIPLY, 1, m, &cBinop_ny4iRSPi_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kFl1YCSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cac99iy6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_lIPJA2Xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CNtwDymI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CNtwDymI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UNeYfla6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7KzCCwHO, m);
}

void Heavy_WSTD_DLAY::cBinop_UNeYfla6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VAH4Lb5P, m);
}

void Heavy_WSTD_DLAY::cVar_hd7LNaJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oMQUj76V, HV_BINOP_MULTIPLY, 0, m, &cBinop_oMQUj76V_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3KIeRZ1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pYdTbQUS_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_pYdTbQUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6vQowDdf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_oMQUj76V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BR2yb5bI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZJ53fFKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oMQUj76V, HV_BINOP_MULTIPLY, 1, m, &cBinop_oMQUj76V_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6vQowDdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZJ53fFKS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_BR2yb5bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mjMfVIjo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_mjMfVIjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6sbiQrZb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hfQZbGJZ, m);
}

void Heavy_WSTD_DLAY::cBinop_6sbiQrZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_blg8DoFC, m);
}

void Heavy_WSTD_DLAY::cBinop_2wL5Wr41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PC6NR91D_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PC6NR91D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SaBrgTQ2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wiJTieCU_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_qpj3XfmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_oaT91Eaf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_35kUOEM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hWD2mpo7_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_hWD2mpo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wSJcH6m2, HV_BINOP_DIVIDE, 1, m, &cBinop_wSJcH6m2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_SaBrgTQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xobfATk7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xobfATk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BjS3mMMH, m);
}

void Heavy_WSTD_DLAY::cMsg_fWLtTKtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WM0IjdyP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WM0IjdyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2wL5Wr41_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wiJTieCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_S8dG0iAP, m);
}

void Heavy_WSTD_DLAY::cBinop_oaT91Eaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_dUrsK73V_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dUrsK73V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wSJcH6m2, HV_BINOP_DIVIDE, 0, m, &cBinop_wSJcH6m2_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wSJcH6m2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fWLtTKtC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_qfCtyoNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U2ZW7wFJ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_VzH7nboF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4S4K2gzt, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ZHdlpLBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KAULjtC0, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_DUFSoGbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_azWmzm9Y, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Nwv7Jan9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ttsH1oah, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_RglNbk1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nveXsIMc, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_dOxVbAc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rq2opJZm, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_kEcAmste_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I5b97TPL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_fRYvu2Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bF7fisAU, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_3XLadDhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PulRztVI, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_hfAcyVjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fG0rzx8S, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_OR7iMrKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o0gdV1f7, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_9nE15uG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OKsSOKVC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fcVER5SA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZFA0NeAN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_OKsSOKVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9nE15uG0, 1, m, &cVar_9nE15uG0_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_FsSbn2Mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_enlDntax, 0, m, &cVar_enlDntax_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_NrYzpGVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_enlDntax, 0, m, &cVar_enlDntax_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_DHAba73I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NrYzpGVr, 0, m, &cIf_NrYzpGVr_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_BS5Q2h0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FsSbn2Mk, 0, m, &cIf_FsSbn2Mk_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_QDtECOrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L52Rw9ln, HV_BINOP_DIVIDE, 0, m, &cBinop_L52Rw9ln_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_LM8yN4Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bsWyDTqy, HV_BINOP_MULTIPLY, 1, m, &cBinop_bsWyDTqy_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_3Vbli5Du_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pIYZBjox, 0, m, &cSlice_pIYZBjox_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tXqqtrZ0, 0, m, &cSlice_tXqqtrZ0_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TlE3iKO5_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6EJfRltw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_pIYZBjox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_TMviFvUc, 0, m, &cVar_TMviFvUc_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TMviFvUc, 0, m, &cVar_TMviFvUc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_tXqqtrZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sJwbQj3V, HV_BINOP_NEQ, 1, m, &cBinop_sJwbQj3V_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TMviFvUc, 1, m, &cVar_TMviFvUc_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sJwbQj3V, HV_BINOP_NEQ, 1, m, &cBinop_sJwbQj3V_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_TMviFvUc, 1, m, &cVar_TMviFvUc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_TMviFvUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_KNk2DWcT_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_G3qHG861_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1iOip3Kb_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aJcDJuZn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_aJcDJuZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TMviFvUc, 0, m, &cVar_TMviFvUc_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_1iOip3Kb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJwbQj3V, HV_BINOP_NEQ, 1, m, &cBinop_sJwbQj3V_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sJwbQj3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G3qHG861, 1, m, &cIf_G3qHG861_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_6EJfRltw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G3qHG861, 0, m, &cIf_G3qHG861_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_TlE3iKO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sJwbQj3V, HV_BINOP_NEQ, 0, m, &cBinop_sJwbQj3V_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_ZEK4GfpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KAlW2V4P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uwjQ9Gak_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_uEwGdGos_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mfaPQzFQ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5tanvQg_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GoNroPyp_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h9C7fzvU_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ovNJD7pG_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wbcNmTJG_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xupyR4ab_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P1247XDf_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NWeR5uL3_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TahlkZMR_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_82Vc3VTb_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tgge0sbV_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V2Eu75yU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_mfaPQzFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iMzrqIHY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_c5tanvQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5MxnffoW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_GoNroPyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v52N4fN4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_h9C7fzvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ukup7TlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ovNJD7pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_odAYebpn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_wbcNmTJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V9EdAS2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_xupyR4ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eaL6UfAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_P1247XDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TSsJUbxf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_NWeR5uL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xYFaC6vM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_TahlkZMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mw54QPwh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_82Vc3VTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nBCy7YML_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Tgge0sbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2gB7HX73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_V2Eu75yU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3qEmuUGt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_L52Rw9ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bsWyDTqy, HV_BINOP_MULTIPLY, 0, m, &cBinop_bsWyDTqy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bsWyDTqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3Vbli5Du_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_uwjQ9Gak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QDtECOrW, 0, m, &cVar_QDtECOrW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LM8yN4Gw, 0, m, &cVar_LM8yN4Gw_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_KAlW2V4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L52Rw9ln, HV_BINOP_DIVIDE, 1, m, &cBinop_L52Rw9ln_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_H3NnOo3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LM8yN4Gw, 0, m, &cVar_LM8yN4Gw_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_MoAQTyD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QDtECOrW, 0, m, &cVar_QDtECOrW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_iMzrqIHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5MxnffoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_v52N4fN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Ukup7TlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_odAYebpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_V9EdAS2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_eaL6UfAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TSsJUbxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_xYFaC6vM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mw54QPwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_nBCy7YML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2gB7HX73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3qEmuUGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H3NnOo3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoAQTyD4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_CUXOc7tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8cZeh1HX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Yk7BYTwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8cZeh1HX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_TvfwoJLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jXIhzPaR, 0, m, &cVar_jXIhzPaR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_c9YSD9cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dH0BPU8U, 0, m, &cVar_dH0BPU8U_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_61sY8qF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IF1ySwN6, 0, m, &cVar_IF1ySwN6_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Nn7FCQ3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8cZeh1HX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_SjGTyJ3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8cZeh1HX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_KNk2DWcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BS5Q2h0q, 0, m, &cVar_BS5Q2h0q_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZFA0NeAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QJijnZUh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KDG4Bnv7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fcVER5SA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pWEPmx4z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pgetcfnk_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Pgetcfnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DHAba73I, 0, m, &cVar_DHAba73I_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_pWEPmx4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NrYzpGVr, 1, m, &cIf_NrYzpGVr_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_QJijnZUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FsSbn2Mk, 1, m, &cIf_FsSbn2Mk_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_KDG4Bnv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BS5Q2h0q, 0, m, &cVar_BS5Q2h0q_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_wJot4Y47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TvfwoJLi_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_NqshwU8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_c9YSD9cu_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_fEpvGyNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_61sY8qF4_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_6vcRQCBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DHAba73I, 0, m, &cVar_DHAba73I_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_1j036xcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fRYvu2Bm_sendMessage(_c, 0, m);
  cMsg_3XLadDhz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_Y4PKzJPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hfAcyVjy_sendMessage(_c, 0, m);
  cMsg_OR7iMrKq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_CzWqHViX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_M3ugDbKx_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_PiRt8jce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m7C6mXqE, 0, m, &cVar_m7C6mXqE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DZYf75z7, 0, m, &cVar_DZYf75z7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6XWvVs5f, 0, m, &cVar_6XWvVs5f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6mTxCtE6, 0, m, &cVar_6mTxCtE6_sendMessage);
  cMsg_eD2ILE33_sendMessage(_c, 0, m);
  cMsg_FGVaYdPH_sendMessage(_c, 0, m);
  cMsg_sIkAA8uN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_n76P4nb3, 0, m, &cVar_n76P4nb3_sendMessage);
  cMsg_YyY7QahA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H2EezniM, 0, m, &cVar_H2EezniM_sendMessage);
  cMsg_lpyr7skc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wNu3UrY3, 0, m, &cVar_wNu3UrY3_sendMessage);
  cMsg_cPoTwHUr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6UGwvqPp, 0, m, &cVar_6UGwvqPp_sendMessage);
  cMsg_3KIeRZ1R_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hd7LNaJM, 0, m, &cVar_hd7LNaJM_sendMessage);
  cMsg_35kUOEM2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qpj3XfmE, 0, m, &cVar_qpj3XfmE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VGqQD9pi, 0, m, &cVar_VGqQD9pi_sendMessage);
  cMsg_F6bAWh5P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z0M2s0WB, 0, m, &cVar_Z0M2s0WB_sendMessage);
  cMsg_TsaUSHuk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_QtqPcuQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7sYVdGlJ_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_DAzOVitb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9nE15uG0, 0, m, &cVar_9nE15uG0_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_3bRTD4rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZEK4GfpF, 0, m, &cVar_ZEK4GfpF_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_qQHzMj0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uEwGdGos_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_4S4K2gzt, VOf(Bf0));
    __hv_line_f(&sLine_bF7fisAU, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_sEflX4v5, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_uDdas4Zy, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_pIPKuBP2, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_Raov78R2, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_CdSoQ3ry, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_N0MeNz6H, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_U2ZW7wFJ, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_KAULjtC0, VOf(Bf0));
    __hv_line_f(&sLine_PulRztVI, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_beWKmHdE, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_q4Q2bFrO, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_FBPULmIu, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_nT1nUZVF, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Ya2GmuYd, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_QFk8qYZi, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_azWmzm9Y, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_K3SCK64Y, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_hXR5vSXX, VIf(Bf0));
    __hv_varread_f(&sVarf_7SSpR10C, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_9tpoVewW, VIf(Bf0));
    __hv_varread_f(&sVarf_vDMJxh7z, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_cm9PoxJG, VOf(Bf1));
    __hv_rpole_f(&sRPole_pXEHEANm, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_B7uJLc7P, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Ernfe2ve, VOf(Bf1));
    __hv_rpole_f(&sRPole_WErpZl35, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Jhttv7Px, VOf(Bf0));
    __hv_rpole_f(&sRPole_1euco1Tx, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_2qG8Tj8s, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_wRETMDYR, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_fG0rzx8S, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_nveXsIMc, VOf(Bf0));
    __hv_varread_f(&sVarf_7KzCCwHO, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_VAH4Lb5P, VOf(Bf4));
    __hv_rpole_f(&sRPole_h93gN1r5, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_hfQZbGJZ, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_blg8DoFC, VOf(Bf4));
    __hv_rpole_f(&sRPole_9IDZnNaH, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_S8dG0iAP, VOf(Bf6));
    __hv_rpole_f(&sRPole_nwoptEYU, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_q9g4JiZz, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_BjS3mMMH, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_o0gdV1f7, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_ttsH1oah, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_K3SCK64Y, VIf(Bf6));
    __hv_line_f(&sLine_I5b97TPL, VOf(Bf6));
    __hv_line_f(&sLine_rq2opJZm, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_7SSpR10C, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
