/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvControlDelay.h"
#include "HvControlUnop.h"
#include "HvControlVar.h"
#include "HvSignalDel1.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"
#include "HvSignalRPole.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvSignalTabwrite.h"
#include "HvSignalTabread.h"
#include "HvTable.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_dH0BPU8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_enlDntax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IF1ySwN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jXIhzPaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JI6VvjnL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GXdb9drL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m7C6mXqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_djI7lQLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8cZeh1HX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_coOiiAdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DZYf75z7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qn4j4LBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hg5pOrNF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VYrJGJyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6XWvVs5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AMOrkY4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M3ugDbKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jmyNKTfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WowsXFbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_l2dTSvF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zOULNShO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jGklqFnQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DZCr0S4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I3Yc62ub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QZ6fJuk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s6tvO0kW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FWRe4DuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zYLSRGQR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d4nT6Zyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7sYVdGlJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TgycaGm4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GLwKMNRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kk2romSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UQfNn930_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xHiyNwc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WvLfAAEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CTxnssus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FrULqHpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XvS7ChVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t4499jQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_31jyaDEZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2BbZguZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6mTxCtE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cJZh2PEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eD2ILE33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_asm98nLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JaWRPAWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CFpGH8PY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kkiIOX2Y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_SOuJM6Po_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_B6anryH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_atAhnVFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_udaIz171_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0vcNuaW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nbmzWP6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AfSsw0gE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lRWAbghY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FGVaYdPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tUwEqGNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Xb5IAQIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nnX3VFqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oVg6SHf4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_jrWMI0FV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_FevYzhFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IgjWL06x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8fGQ4I4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pjjfyOEt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JGx49eZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_luG5GKl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OB16DVcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n76P4nb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sIkAA8uN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vGIIHTs1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pO5Gs2uQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8Ug9lpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_twu8ScE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uemk64M2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DonawLwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qWG5DDC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H2EezniM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YyY7QahA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kxrbVIGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L7RO3Bab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D7pC7YSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZhdpMuKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0cOv4GVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dGjSgjZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7f3PHJbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aeHHQ3K3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4hlOHCef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wNu3UrY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lpyr7skc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6K82KAnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jtmr74QS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1zBCUVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DDELUWtR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d9qKF3JA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8fBCijK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2nKrYAHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1aeoAfgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qHNofJNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F6bAWh5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zXTw72Es_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VGqQD9pi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XrrtiLlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YBQEuWZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PWIsPzWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QToQ8GP0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TsaUSHuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_P58rRX3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z0M2s0WB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UTxi4N9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GmY02Bkw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iwT1dz76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ByZLnnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6UGwvqPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cPoTwHUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UMVjVrq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ny4iRSPi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cac99iy6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kFl1YCSB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lIPJA2Xv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CNtwDymI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UNeYfla6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hd7LNaJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3KIeRZ1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pYdTbQUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oMQUj76V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJ53fFKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6vQowDdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BR2yb5bI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mjMfVIjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6sbiQrZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2wL5Wr41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PC6NR91D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qpj3XfmE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_35kUOEM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hWD2mpo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SaBrgTQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xobfATk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWLtTKtC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WM0IjdyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wiJTieCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oaT91Eaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dUrsK73V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wSJcH6m2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qfCtyoNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VzH7nboF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZHdlpLBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DUFSoGbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nwv7Jan9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RglNbk1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dOxVbAc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kEcAmste_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fRYvu2Bm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3XLadDhz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hfAcyVjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OR7iMrKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9nE15uG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OKsSOKVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FsSbn2Mk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NrYzpGVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DHAba73I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BS5Q2h0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QDtECOrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LM8yN4Gw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3Vbli5Du_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pIYZBjox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_tXqqtrZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TMviFvUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_G3qHG861_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aJcDJuZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1iOip3Kb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sJwbQj3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6EJfRltw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TlE3iKO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZEK4GfpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uEwGdGos_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_mfaPQzFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c5tanvQg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GoNroPyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h9C7fzvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ovNJD7pG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wbcNmTJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xupyR4ab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P1247XDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NWeR5uL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TahlkZMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_82Vc3VTb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tgge0sbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V2Eu75yU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L52Rw9ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bsWyDTqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uwjQ9Gak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KAlW2V4P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H3NnOo3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MoAQTyD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iMzrqIHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5MxnffoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v52N4fN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ukup7TlZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_odAYebpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V9EdAS2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eaL6UfAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TSsJUbxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xYFaC6vM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mw54QPwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBCy7YML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2gB7HX73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3qEmuUGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CUXOc7tf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yk7BYTwV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TvfwoJLi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c9YSD9cu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_61sY8qF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nn7FCQ3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SjGTyJ3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KNk2DWcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZFA0NeAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fcVER5SA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pgetcfnk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pWEPmx4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QJijnZUh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KDG4Bnv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wJot4Y47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NqshwU8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fEpvGyNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6vcRQCBV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1j036xcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y4PKzJPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CzWqHViX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PiRt8jce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QtqPcuQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DAzOVitb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3bRTD4rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qQHzMj0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_4S4K2gzt;
  SignalLine sLine_bF7fisAU;
  SignalTabhead sTabhead_sEflX4v5;
  SignalTabread sTabread_CdSoQ3ry;
  SignalTabread sTabread_N0MeNz6H;
  SignalLine sLine_U2ZW7wFJ;
  SignalLine sLine_KAULjtC0;
  SignalLine sLine_PulRztVI;
  SignalTabhead sTabhead_beWKmHdE;
  SignalTabread sTabread_Ya2GmuYd;
  SignalTabread sTabread_QFk8qYZi;
  SignalLine sLine_azWmzm9Y;
  SignalTabwrite sTabwrite_hXR5vSXX;
  SignalTabwrite sTabwrite_9tpoVewW;
  SignalRPole sRPole_pXEHEANm;
  SignalRPole sRPole_WErpZl35;
  SignalRPole sRPole_1euco1Tx;
  SignalDel1 sDel1_2qG8Tj8s;
  SignalLine sLine_fG0rzx8S;
  SignalLine sLine_nveXsIMc;
  SignalRPole sRPole_h93gN1r5;
  SignalRPole sRPole_9IDZnNaH;
  SignalRPole sRPole_nwoptEYU;
  SignalDel1 sDel1_q9g4JiZz;
  SignalLine sLine_o0gdV1f7;
  SignalLine sLine_ttsH1oah;
  SignalLine sLine_I5b97TPL;
  SignalLine sLine_rq2opJZm;
  ControlVar cVar_dH0BPU8U;
  ControlVar cVar_enlDntax;
  ControlVar cVar_IF1ySwN6;
  ControlVar cVar_jXIhzPaR;
  ControlSlice cSlice_GXdb9drL;
  ControlVar cVar_m7C6mXqE;
  ControlSlice cSlice_coOiiAdT;
  ControlVar cVar_DZYf75z7;
  ControlSlice cSlice_VYrJGJyb;
  ControlVar cVar_6XWvVs5f;
  ControlBinop cBinop_M3ugDbKx;
  ControlBinop cBinop_jmyNKTfQ;
  ControlBinop cBinop_zOULNShO;
  ControlBinop cBinop_jGklqFnQ;
  ControlBinop cBinop_QZ6fJuk0;
  ControlBinop cBinop_FWRe4DuE;
  ControlBinop cBinop_zYLSRGQR;
  ControlBinop cBinop_d4nT6Zyv;
  ControlBinop cBinop_7sYVdGlJ;
  ControlBinop cBinop_TgycaGm4;
  ControlBinop cBinop_GLwKMNRc;
  ControlBinop cBinop_Kk2romSK;
  ControlBinop cBinop_WvLfAAEl;
  ControlBinop cBinop_FrULqHpz;
  ControlBinop cBinop_XvS7ChVs;
  ControlBinop cBinop_t4499jQI;
  ControlSlice cSlice_2BbZguZ4;
  ControlVar cVar_6mTxCtE6;
  ControlDelay cDelay_JaWRPAWV;
  ControlDelay cDelay_CFpGH8PY;
  ControlBinop cBinop_SOuJM6Po;
  HvTable hTable_B6anryH3;
  ControlBinop cBinop_udaIz171;
  ControlDelay cDelay_Xb5IAQIy;
  ControlDelay cDelay_nnX3VFqD;
  ControlBinop cBinop_jrWMI0FV;
  HvTable hTable_FevYzhFZ;
  ControlBinop cBinop_8fGQ4I4e;
  ControlVar cVar_n76P4nb3;
  ControlBinop cBinop_pO5Gs2uQ;
  ControlBinop cBinop_k8Ug9lpI;
  SignalVarf sVarf_cm9PoxJG;
  ControlBinop cBinop_uemk64M2;
  ControlBinop cBinop_DonawLwT;
  ControlBinop cBinop_qWG5DDC0;
  SignalVarf sVarf_vDMJxh7z;
  ControlVar cVar_H2EezniM;
  ControlBinop cBinop_L7RO3Bab;
  ControlBinop cBinop_D7pC7YSz;
  SignalVarf sVarf_Ernfe2ve;
  ControlBinop cBinop_0cOv4GVa;
  ControlBinop cBinop_dGjSgjZF;
  ControlBinop cBinop_7f3PHJbd;
  SignalVarf sVarf_B7uJLc7P;
  ControlBinop cBinop_aeHHQ3K3;
  ControlBinop cBinop_4hlOHCef;
  SignalVarf sVarf_Jhttv7Px;
  ControlVar cVar_wNu3UrY3;
  ControlBinop cBinop_jtmr74QS;
  ControlBinop cBinop_f1zBCUVL;
  ControlBinop cBinop_d9qKF3JA;
  ControlBinop cBinop_8fBCijK2;
  ControlBinop cBinop_2nKrYAHs;
  ControlBinop cBinop_1aeoAfgO;
  ControlBinop cBinop_qHNofJNN;
  SignalVarf sVarf_wRETMDYR;
  ControlVar cVar_VGqQD9pi;
  ControlBinop cBinop_YBQEuWZq;
  ControlBinop cBinop_QToQ8GP0;
  SignalVarf sVarf_Raov78R2;
  SignalVarf sVarf_uDdas4Zy;
  SignalVarf sVarf_pIPKuBP2;
  ControlVar cVar_Z0M2s0WB;
  ControlBinop cBinop_GmY02Bkw;
  ControlBinop cBinop_7ByZLnnv;
  SignalVarf sVarf_nT1nUZVF;
  SignalVarf sVarf_q4Q2bFrO;
  SignalVarf sVarf_FBPULmIu;
  ControlVar cVar_6UGwvqPp;
  ControlBinop cBinop_ny4iRSPi;
  ControlBinop cBinop_cac99iy6;
  SignalVarf sVarf_VAH4Lb5P;
  ControlBinop cBinop_lIPJA2Xv;
  ControlBinop cBinop_CNtwDymI;
  ControlBinop cBinop_UNeYfla6;
  SignalVarf sVarf_7KzCCwHO;
  ControlVar cVar_hd7LNaJM;
  ControlBinop cBinop_oMQUj76V;
  ControlBinop cBinop_ZJ53fFKS;
  SignalVarf sVarf_blg8DoFC;
  ControlBinop cBinop_BR2yb5bI;
  ControlBinop cBinop_mjMfVIjo;
  ControlBinop cBinop_6sbiQrZb;
  SignalVarf sVarf_hfQZbGJZ;
  ControlBinop cBinop_2wL5Wr41;
  ControlBinop cBinop_PC6NR91D;
  SignalVarf sVarf_S8dG0iAP;
  ControlVar cVar_qpj3XfmE;
  ControlBinop cBinop_SaBrgTQ2;
  ControlBinop cBinop_xobfATk7;
  ControlBinop cBinop_WM0IjdyP;
  ControlBinop cBinop_wiJTieCU;
  ControlBinop cBinop_oaT91Eaf;
  ControlBinop cBinop_dUrsK73V;
  ControlBinop cBinop_wSJcH6m2;
  SignalVarf sVarf_BjS3mMMH;
  SignalVarf sVarf_K3SCK64Y;
  SignalVarf sVarf_7SSpR10C;
  ControlVar cVar_9nE15uG0;
  ControlBinop cBinop_OKsSOKVC;
  ControlIf cIf_FsSbn2Mk;
  ControlIf cIf_NrYzpGVr;
  ControlVar cVar_DHAba73I;
  ControlVar cVar_BS5Q2h0q;
  ControlVar cVar_QDtECOrW;
  ControlVar cVar_LM8yN4Gw;
  ControlSlice cSlice_pIYZBjox;
  ControlSlice cSlice_tXqqtrZ0;
  ControlVar cVar_TMviFvUc;
  ControlIf cIf_G3qHG861;
  ControlBinop cBinop_sJwbQj3V;
  ControlVar cVar_ZEK4GfpF;
  ControlBinop cBinop_L52Rw9ln;
  ControlBinop cBinop_bsWyDTqy;
  ControlBinop cBinop_TvfwoJLi;
  ControlBinop cBinop_c9YSD9cu;
  ControlBinop cBinop_61sY8qF4;
  ControlBinop cBinop_KNk2DWcT;
  ControlBinop cBinop_ZFA0NeAN;
  ControlBinop cBinop_fcVER5SA;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
